@@ -3,9 +3,9 @@ Main interface for cloudhsm service type definitions.
 
 Usage::
 
-    from mypy_boto3.cloudhsm.type_defs import AddTagsToResourceResponseTypeDef
+    from mypy_boto3.cloudhsm.type_defs import TagTypeDef
 
-    data: AddTagsToResourceResponseTypeDef = {...}
+    data: TagTypeDef = {...}
 """
 import sys
 from typing import List
@@ -21,6 +21,7 @@ else:
 
 
 __all__ = (
+    "TagTypeDef",
     "AddTagsToResourceResponseTypeDef",
     "CreateHapgResponseTypeDef",
     "CreateHsmResponseTypeDef",
@@ -36,7 +37,6 @@ __all__ = (
     "ListHapgsResponseTypeDef",
     "ListHsmsResponseTypeDef",
     "ListLunaClientsResponseTypeDef",
-    "TagTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "ModifyHapgResponseTypeDef",
     "ModifyHsmResponseTypeDef",
@@ -45,6 +45,8 @@ __all__ = (
     "RemoveTagsFromResourceResponseTypeDef",
 )
 
+TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
+
 AddTagsToResourceResponseTypeDef = TypedDict("AddTagsToResourceResponseTypeDef", {"Status": str})
 
 CreateHapgResponseTypeDef = TypedDict("CreateHapgResponseTypeDef", {"HapgArn": str}, total=False)
@@ -161,10 +163,8 @@ class ListLunaClientsResponseTypeDef(
     pass
 
 
-TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
-
 ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef", {"TagList": List[TagTypeDef]}
+    "ListTagsForResourceResponseTypeDef", {"TagList": List["TagTypeDef"]}
 )
 
 ModifyHapgResponseTypeDef = TypedDict("ModifyHapgResponseTypeDef", {"HapgArn": str}, total=False)
